@@ -135,6 +135,8 @@ class ChildReaper(object):
             self.check()
 
     def reap(self):
+        if not self.check():
+            return
         while True:
             try:
                 pid, _ = os.waitpid(-1, os.WNOHANG)
@@ -790,8 +792,12 @@ def run_server(error_cb, opts, mode, xpra_file, extra_args):
 
     #get the display name:
     if shadowing and len(extra_args)==0:
-        from xpra.scripts.main import guess_X11_display
-        display_name = guess_X11_display(opts.socket_dir)
+        if sys.platform.startswith("win") or sys.platform.startswith("darwin"):
+            #just a virtual name for the only display available:
+            display_name = ":0"
+        else:
+            from xpra.scripts.main import guess_X11_display
+            display_name = guess_X11_display(opts.socket_dir)
     elif upgrading and len(extra_args)==0:
         from xpra.scripts.main import guess_xpra_display
         display_name = guess_xpra_display(opts.socket_dir)
