@@ -531,7 +531,7 @@ class BaseWindowModel(AutoPropGObjectMixin, gobject.GObject):
             # see if it's override-redirect (and if so treat as NORMAL).
             # But we wouldn't be here if this was override-redirect.
             # (OverrideRedirectWindowModel overrides this method)
-            return "_NET_WM_TYPE_DIALOG"
+            return "_NET_WM_WINDOW_TYPE_DIALOG"
         return "_NET_WM_WINDOW_TYPE_NORMAL"
 
     def is_tray(self):
@@ -1233,7 +1233,9 @@ class WindowModel(BaseWindowModel):
         #motif_hints = self.prop_get("_MOTIF_WM_HINTS", "motif-hints")
         motif_hints = prop_get(self.client_window, "_MOTIF_WM_HINTS", "motif-hints", ignore_errors=False, raise_xerrors=True)
         log("_handle_motif_wm_hints() motif_hints=%s", motif_hints)
-        self._internal_set_property("decorations", (motif_hints is None) or bool(motif_hints.decorations))
+        DECORATIONS_BIT = 1
+        if motif_hints and motif_hints.flags&(2**DECORATIONS_BIT):
+            self._internal_set_property("decorations", motif_hints.decorations)
     _property_handlers["_MOTIF_WM_HINTS"] = _handle_motif_wm_hints
 
     def _handle_net_wm_icon(self):
